@@ -90,7 +90,7 @@ def itemgetter(it: Iterable[T]) -> Callable[[Mapping[T, U]], Iterator[U]]:
     return lambda d: (d[i] for i in it)
 
 
-def subdictdefault(d: Mapping[T, U], it: Iterable[T], default: Union[U, V] = None) -> Dict[T, Union[U, V]]:
+def subdictdefault(d: Mapping[T, U], it: Iterable[T], default: V = None) -> Dict[T, Union[U, V]]:
 
     """Uses the elements of `it` as keys to extract a new sub-dictionary."""
 
@@ -115,7 +115,7 @@ class keydefaultdict(defaultdict):
         if self.default_factory is None:
             raise KeyError(key)
         else:
-            value = self[key] = self.default_factory(key)
+            value = self[key] = self.default_factory(key)  # type: ignore[call-arg]
             return value
 
 
@@ -135,6 +135,9 @@ class NoOverwriteDict(UserDict):
     def overwrite(self, key: Hashable, value: Any) -> None:
         self.data[key] = value
 
+    def dict(self):
+        return self.data
+
 
 def _merge_schema(d1: dict, d2: dict) -> None:
 
@@ -212,3 +215,17 @@ def get_schema_simple(d: Iterable[dict]) -> dict:
 
     _post_schema(schema)
     return schema
+
+
+# was: zipmap
+def zipget(objs: Iterable[Mapping[T, U]], keys: Iterable[T]) -> Iterator[U]:
+
+    """Gets a list of keys from a list of mappings.
+        zipget([[1, 2], [3, 4]], [0, 1]) -> (1, 4)
+
+    Similar to numpy indexing:
+        a = np.array([[1, 2], [3, 4]])
+        a[np.arange(len(a)), [0, 1]] -> array([1, 4])
+    """
+
+    return (obj[key] for obj, key in zip(objs, keys))
