@@ -5,11 +5,11 @@ from typing import TYPE_CHECKING
 from nltk.tokenize import word_tokenize
 
 if TYPE_CHECKING:
-	from os import PathLike
+    from os import PathLike
 
 
 def count_words_in_file(path, encoding="utf-8"):
-	# type: (PathLike, str) -> int
+    # type: (PathLike, str) -> int
 
-	with open(path, "r", encoding=encoding) as fr:
-		return sum(len(word_tokenize(line)) for line in fr)
+    with open(path, encoding=encoding) as fr:
+        return sum(len(word_tokenize(line)) for line in fr)
