@@ -20,7 +20,8 @@ def join_pdfs_in_folder(path_in: Path, file_out: PathType, overwrite: bool = Fal
         raise FileNotFoundError(path_in)
 
     with ExitStack() as stack:
-        for path in path_in.glob("*.pdf"):
+        paths = sorted(path_in.glob("*.pdf"))
+        for path in paths:
             if path.is_file():
                 fr = stack.enter_context(path.open("rb"))  # open does not support Path in <3.6
                 merger.append(fr)
