@@ -1,10 +1,7 @@
 from __future__ import generator_stop
 
 import re
-from typing import TYPE_CHECKING
-
-if TYPE_CHECKING:
-    from typing import List
+from typing import List
 
 re_paragraphs = re.compile(r"((?:[^\n][\n]?)+)")
 
